# 开发包

dev = [
  "pdm",
  "pygame",
  "PyGithub[integrations]",
  "bytecode",
  "numpy",
  "fsspec",
  "pyarrow",
  "openpyxl",
  "rich[jupyter]",
  "grpcio",
  "absl-py",
  "ping3",
  "paramiko",
  "tables",
]